Zarr
====

Zarr is a Python package providing an implementation of compressed,
chunked, N-dimensional arrays, designed for use in parallel
computing. See the `documentation <http://zarr.readthedocs.io/>`_ for
more information.

.. image:: https://travis-ci.org/alimanfoo/zarr.svg?branch=master
    :target: https://travis-ci.org/alimanfoo/zarr

.. image:: https://ci.appveyor.com/api/projects/status/7d4iko59k8hpbbik?svg=true
    :target: https://ci.appveyor.com/project/alimanfoo/zarr
